let popupActive = false;
let hoverTimeout = null;
let pendingCheckTimeout = null;
let currentTarget = null;
let isHovering = false;
let lastCheckedURL = null; // משתנה לשמירת הקישור שנבדק

document.addEventListener("mouseover", (event) => {
  const target = event.target.closest("a");
  if (!target) return;
  
  // מעדכן את הקישור הנוכחי ודגל הריחוף
  currentTarget = target;
  isHovering = true;
  
  // אם אין פופ-אפ פעיל, מתחילים להמתין חצי שניה לבדיקה
  if (!popupActive) {
    clearTimeout(hoverTimeout);
    hoverTimeout = setTimeout(() => {
      checkLink(target);
    }, 500);
  }
  // אם יש פופ-אפ פעיל – לא נבצע כלום
});

document.addEventListener("mouseout", (event) => {
  const target = event.target.closest("a");
  if (!target) return;
  if (currentTarget === target) {
    isHovering = false;
    clearTimeout(hoverTimeout);
    clearTimeout(pendingCheckTimeout);
  }
});

function checkLink(target) {
  const url = target.href;
  if (!url) return;
  
  // אם הקישור כבר נבדק, לא נבצע בדיקה נוספת
  if (url === lastCheckedURL) return;
  
  // עדכון הקישור שנבדק
  lastCheckedURL = url;
  
  const currentDomain = window.location.hostname;
  const linkDomain = new URL(url).hostname;
  if (currentDomain === linkDomain) return;
  
  // שולח בקשה ל-background.js לבדוק את הקישור
  chrome.runtime.sendMessage({ url: url }, (response) => {
    if (response.status === 418) {
      showPopup(target, "❌ הקישור חסום");
    } else {
      showPopup(target, "✅ הקישור פתוח");
    }
  });
}

function showPopup(target, message) {
  popupActive = true;
  let popup = document.createElement("div");
  popup.innerText = message;
  popup.style.position = "absolute";
  popup.style.background = "#000";
  popup.style.color = "#fff";
  popup.style.padding = "5px";
  popup.style.borderRadius = "5px";
  popup.style.fontSize = "12px";
  popup.style.zIndex = "9999";
  
  document.body.appendChild(popup);
  
  const rect = target.getBoundingClientRect();
  popup.style.left = `${rect.left + window.scrollX}px`;
  popup.style.top = `${rect.top + window.scrollY - 30}px`;
  
  // הפופ-אפ יוצג למשך 2 שניות
  setTimeout(() => {
    removePopup(popup);
  }, 2000);
}

function removePopup(popup) {
  if (popup && popup.parentNode) {
    popup.parentNode.removeChild(popup);
  }
  popupActive = false;
  
  // לאחר הסרת הפופ-אפ, אם המשתמש עדיין מרחף על קישור, נמתין חצי שניה ונבדוק אותו,
  // אך רק אם הקישור טרי (לא נבדק כבר)
  if (currentTarget && isHovering) {
    pendingCheckTimeout = setTimeout(() => {
      checkLink(currentTarget);
    }, 500);
  }
}
